@@ -101,14 +101,11 @@ impl RgbaOutputFile {
     /// * [`Error::Base`] - If an error occurs
     ///
     #[allow(clippy::too_many_arguments)]
-    pub fn with_dimensions<P: AsRef<Path>, V>(
+    pub fn with_dimensions<P: AsRef<Path>>(
         filename: P,
         width: i32,
         height: i32,
-    ) -> Result<RgbaOutputFile>
-    where
-        V: Vec2<f32>,
-    {
+    ) -> Result<RgbaOutputFile> {
         let c_filename = CString::new(
             filename
                 .as_ref()
